# `pytyper-weather-forecast`

**Installation**:
```console
$ pip install pytyper-weather-forecast
```

**Usage**:

```console
$ pytyper-weather-forecast [OPTIONS] CITY
```

**Arguments**:

* `CITY`: [required]

**Options**:

* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, **to** copy it or customize the installation.
* `--help`: Show this message and exit.
